@@ -18,9 +18,8 @@
 
 use generic_array::typenum::Unsigned;
 use p256::elliptic_curve;
-use prost::Message;
 use tink_core::{utils::wrap_err, TinkError};
-use tink_proto::EllipticCurveType;
+use tink_proto::{prost::Message, EllipticCurveType};
 
 /// Maximal version of ECDSA keys.
 pub const ECDSA_SIGNER_KEY_VERSION: u32 = 0;
@@ -76,7 +75,7 @@ impl tink_core::registry::KeyManager for EcdsaSignerKeyManager {
                 //  - P bytes of X coordinate
                 //  - P bytes of Y coordinate
                 // where P is the field element size.
-                let point_len = <p256::NistP256 as elliptic_curve::Curve>::FieldSize::to_usize();
+                let point_len = elliptic_curve::FieldSize::<p256::NistP256>::to_usize();
                 if public_key_data.len() != 2 * point_len + 1
                     || public_key_data[0] != ECDSA_UNCOMPRESSED_POINT_PREFIX
                 {
