@@ -16,8 +16,8 @@
 
 //! Key manager for ECDSA verification keys.
 
-use prost::Message;
 use tink_core::{utils::wrap_err, TinkError};
+use tink_proto::prost::Message;
 
 /// Maximal version of ECDSA keys.
 pub const ECDSA_VERIFIER_KEY_VERSION: u32 = 0;
