@@ -81,7 +81,7 @@ impl EcdsaVerifier {
 pub fn element_from_padded_slice<C: elliptic_curve::Curve>(
     data: &[u8],
 ) -> Result<elliptic_curve::FieldBytes<C>, TinkError> {
-    let point_len = C::FieldSize::to_usize();
+    let point_len = elliptic_curve::FieldSize::<C>::to_usize();
     if data.len() >= point_len {
         let offset = data.len() - point_len;
         for v in data.iter().take(offset) {
